/***************************************************************************
 begin                : Wed Mar 13 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITORLIMIT_H
#define KMFRULEEDITORLIMIT_H
#include "kmyfirewallruleeditorlimit.h"

#include <tqwidget.h>

/**
  *@author Christian Hubinger
  */
  namespace KMF {
class IPTRule;

class KMFRuleEditorLimit : public KMyFirewallRuleEditorLimit {
	TQ_OBJECT
  
public:
	KMFRuleEditorLimit( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditorLimit();

	void loadRule( IPTRule* );

public slots:    // Public slots
	void slotOk();
	void readRuleConfig();
	void slotHelp();
	void reject();

private:
	IPTRule* m_rule;

signals:
/*	void sigAddRuleOpt( TQString*, TQPtrList<TQString>* );
	void sigAddTargetOpt( TQString*, TQPtrList<TQString>* );*/
	void sigHideMe();
};
}
#endif
